@@ -29,7 +29,7 @@ class Stream:
 
   def group_by(self, name=None, emits=None, fields=None, prepare=None, begin_group=None, aggregate=None, end_group=None, parallelism=None):
     op = OperationHandler(self._app, self.__class__)
-    streams = op.build_multilang_operation("group_by", name, emits, fields, begin_group, aggregate, end_group, parallelism)\
+    streams = op.build_multilang_operation("group_by", name, emits, fields, prepare, begin_group, aggregate, end_group, parallelism)\
                 .add_operation_properties_to_info("name", "type", "group_by")\
                 .add_optional_operation_properties_to_info("parallelism")\
                 .create_arc_info_from_stream(self)\
